@@ -28,7 +28,7 @@
  *        so the performance scores calculated with this code
  *        should NOT be used to compare with other HTTP servers
  *        (since MHD is actually better); only the relative
- *        scores between MHD versions are meaningful.  
+ *        scores between MHD versions are meaningful.
  * @author Christian Grothoff
  */
 
@@ -75,13 +75,18 @@ static struct MHD_Response *response;
  */
 static unsigned long long start_time;
 
+/**
+ * Set to 1 if the worker threads are done.
+ */
+static volatile int signal_done;
+
 
 /**
- * Get the current timestamp 
+ * Get the current timestamp
  *
  * @return current time in ms
  */
-static unsigned long long 
+static unsigned long long
 now ()
 {
   struct timeval tv;
@@ -95,7 +100,7 @@ now ()
 /**
  * Start the timer.
  */
-static void 
+static void
 start_timer()
 {
   start_time = now ();
@@ -107,7 +112,7 @@ start_timer()
  *
  * @param desc description of the threading mode we used
  */
-static void 
+static void
 stop (const char *desc)
 {
   double rps = ((double) (PAR * ROUNDS * 1000)) / ((double) (now() - start_time));
@@ -125,13 +130,14 @@ stop (const char *desc)
 
 
 static size_t
-copyBuffer (void *ptr, 
-	    size_t size, size_t nmemb, 
+copyBuffer (void *ptr,
+	    size_t size, size_t nmemb,
 	    void *ctx)
 {
   return size * nmemb;
 }
 
+
 static int
 ahc_echo (void *cls,
           struct MHD_Connection *connection,
@@ -159,6 +165,7 @@ ahc_echo (void *cls,
   return ret;
 }
 
+
 static void *
 thread_gets (void *param)
 {
@@ -198,6 +205,7 @@ thread_gets (void *param)
   return NULL;
 }
 
+
 static void *
 do_gets (void * param)
 {
@@ -225,6 +233,7 @@ do_gets (void * param)
           NULL != ret_val)
         err = ret_val;
     }
+  signal_done = 1;
   return err;
 }
 
@@ -233,10 +242,13 @@ static int
 testInternalGet (int port, int poll_flag)
 {
   struct MHD_Daemon *d;
-  const char * const test_desc = poll_flag ? "internal poll" : "internal select";
+  const char * const test_desc = ((poll_flag & MHD_USE_AUTO) ? "internal thread with 'auto'" :
+                                  (poll_flag & MHD_USE_POLL) ? "internal thread with poll()" :
+                                  (poll_flag & MHD_USE_EPOLL) ? "internal thread with epoll" : "internal thread with select()");
   const char * ret_val;
 
-  d = MHD_start_daemon (MHD_USE_SELECT_INTERNALLY | MHD_USE_DEBUG  | poll_flag,
+  signal_done = 0;
+  d = MHD_start_daemon (MHD_USE_INTERNAL_POLLING_THREAD | MHD_USE_ERROR_LOG  | poll_flag,
                         port, NULL, NULL, &ahc_echo, "GET", MHD_OPTION_END);
   if (d == NULL)
     return 1;
@@ -259,10 +271,14 @@ static int
 testMultithreadedGet (int port, int poll_flag)
 {
   struct MHD_Daemon *d;
-  const char * const test_desc = poll_flag ? "thread with poll" : "thread with select";
+  const char * const test_desc = ((poll_flag & MHD_USE_AUTO) ? "internal thread with 'auto' and thread per connection" :
+                                  (poll_flag & MHD_USE_POLL) ? "internal thread with poll() and thread per connection" :
+                                  (poll_flag & MHD_USE_EPOLL) ? "internal thread with epoll and thread per connection"
+                                      : "internal thread with select() and thread per connection");
   const char * ret_val;
 
-  d = MHD_start_daemon (MHD_USE_THREAD_PER_CONNECTION | MHD_USE_DEBUG  | poll_flag,
+  signal_done = 0;
+  d = MHD_start_daemon (MHD_USE_THREAD_PER_CONNECTION | MHD_USE_INTERNAL_POLLING_THREAD | MHD_USE_ERROR_LOG  | poll_flag,
                         port, NULL, NULL, &ahc_echo, "GET", MHD_OPTION_END);
   if (d == NULL)
     return 16;
@@ -280,14 +296,18 @@ testMultithreadedGet (int port, int poll_flag)
   return 0;
 }
 
+
 static int
 testMultithreadedPoolGet (int port, int poll_flag)
 {
   struct MHD_Daemon *d;
-  const char * const test_desc = poll_flag ? "thread pool with poll" : "thread pool with select";
+  const char * const test_desc = ((poll_flag & MHD_USE_AUTO) ? "internal thread pool with 'auto'" :
+                                  (poll_flag & MHD_USE_POLL) ? "internal thread pool with poll()" :
+                                  (poll_flag & MHD_USE_EPOLL) ? "internal thread poll with epoll" : "internal thread pool with select()");
   const char * ret_val;
 
-  d = MHD_start_daemon (MHD_USE_SELECT_INTERNALLY | MHD_USE_DEBUG | poll_flag,
+  signal_done = 0 ;
+  d = MHD_start_daemon (MHD_USE_INTERNAL_POLLING_THREAD | MHD_USE_ERROR_LOG | poll_flag,
                         port, NULL, NULL, &ahc_echo, "GET",
                         MHD_OPTION_THREAD_POOL_SIZE, CPU_COUNT, MHD_OPTION_END);
   if (d == NULL)
@@ -306,6 +326,7 @@ testMultithreadedPoolGet (int port, int poll_flag)
   return 0;
 }
 
+
 static int
 testExternalGet (int port)
 {
@@ -321,17 +342,20 @@ testExternalGet (int port)
   char *ret_val;
   int ret = 0;
 
-  d = MHD_start_daemon (MHD_USE_DEBUG,
+  signal_done = 0;
+  d = MHD_start_daemon (MHD_USE_ERROR_LOG,
                         port, NULL, NULL, &ahc_echo, "GET", MHD_OPTION_END);
   if (d == NULL)
     return 256;
-  if (0 != pthread_create(&pid, NULL, &do_gets, (void*)(intptr_t)port))
+  if (0 != pthread_create (&pid, NULL,
+			   &do_gets, (void*)(intptr_t)port))
     {
       MHD_stop_daemon(d);
       return 512;
     }
   start_timer ();
-  while (ESRCH != pthread_kill (pid, 0))
+
+  while (0 == signal_done)
     {
       max = 0;
       FD_ZERO (&rs);
@@ -354,7 +378,7 @@ testExternalGet (int port)
 		   "select failed: %s\n",
 		   strerror (errno));
 	  ret |= 1024;
-	  break;	      	  
+	  break;
 	}
       MHD_run_from_select(d, &rs, &ws, &es);
     }
@@ -391,6 +415,9 @@ main (int argc, char *const *argv)
   errorCount += testMultithreadedGet (port++, 0);
   errorCount += testMultithreadedPoolGet (port++, 0);
   errorCount += testExternalGet (port++);
+  errorCount += testInternalGet (port++, MHD_USE_AUTO);
+  errorCount += testMultithreadedGet (port++, MHD_USE_AUTO);
+  errorCount += testMultithreadedPoolGet (port++, MHD_USE_AUTO);
   if (MHD_YES == MHD_is_feature_supported(MHD_FEATURE_POLL))
     {
       errorCount += testInternalGet (port++, MHD_USE_POLL);
