@@ -35,6 +35,9 @@
 #include <sys/types.h>
 #include <sys/wait.h>
 #include <fcntl.h>
+#ifdef __sun
+#include <signal.h>
+#endif /* __sun */
 
 #ifndef WINDOWS
 #include <sys/socket.h>
@@ -77,6 +80,7 @@ fork_curl (const char *url)
   _exit (-1);
 }
 
+
 static void
 kill_curl (pid_t pid)
 {
@@ -97,6 +101,7 @@ push_callback (void *cls, uint64_t pos, char *buf, size_t max)
   return 1;
 }
 
+
 static void
 push_free_callback (void *cls)
 {
@@ -150,7 +155,7 @@ testInternalGet ()
   pid_t curl;
 
   ok = 1;
-  d = MHD_start_daemon (MHD_USE_SELECT_INTERNALLY | MHD_USE_DEBUG,
+  d = MHD_start_daemon (MHD_USE_INTERNAL_POLLING_THREAD | MHD_USE_ERROR_LOG,
                         11080, NULL, NULL, &ahc_echo, "GET", MHD_OPTION_END);
   if (d == NULL)
     return 1;
@@ -165,19 +170,20 @@ testInternalGet ()
   return 0;
 }
 
+
 static int
 testMultithreadedGet ()
 {
   struct MHD_Daemon *d;
   pid_t curl;
 
-  d = MHD_start_daemon (MHD_USE_THREAD_PER_CONNECTION | MHD_USE_DEBUG,
+  ok = 1;
+  d = MHD_start_daemon (MHD_USE_THREAD_PER_CONNECTION | MHD_USE_INTERNAL_POLLING_THREAD | MHD_USE_ERROR_LOG,
                         1081, NULL, NULL, &ahc_echo, "GET",
 			MHD_OPTION_CONNECTION_TIMEOUT, (unsigned int) 2,
 			MHD_OPTION_END);
   if (d == NULL)
     return 16;
-  ok = 1;
   //fprintf (stderr, "Forking cURL!\n");
   curl = fork_curl ("http://127.0.0.1:1081/");
   sleep (1);
@@ -201,18 +207,19 @@ testMultithreadedGet ()
   return 0;
 }
 
+
 static int
 testMultithreadedPoolGet ()
 {
   struct MHD_Daemon *d;
   pid_t curl;
 
-  d = MHD_start_daemon (MHD_USE_SELECT_INTERNALLY | MHD_USE_DEBUG,
+  ok = 1;
+  d = MHD_start_daemon (MHD_USE_INTERNAL_POLLING_THREAD | MHD_USE_ERROR_LOG,
                         1081, NULL, NULL, &ahc_echo, "GET",
                         MHD_OPTION_THREAD_POOL_SIZE, CPU_COUNT, MHD_OPTION_END);
   if (d == NULL)
     return 64;
-  ok = 1;
   curl = fork_curl ("http://127.0.0.1:1081/");
   sleep (1);
   kill_curl (curl);
@@ -224,6 +231,7 @@ testMultithreadedPoolGet ()
   return 0;
 }
 
+
 static int
 testExternalGet ()
 {
@@ -236,7 +244,8 @@ testExternalGet ()
   struct timeval tv;
   pid_t curl;
 
-  d = MHD_start_daemon (MHD_USE_DEBUG,
+  ok = 1;
+  d = MHD_start_daemon (MHD_USE_ERROR_LOG,
                         1082, NULL, NULL, &ahc_echo, "GET", MHD_OPTION_END);
   if (d == NULL)
     return 256;
@@ -297,6 +306,13 @@ int
 main (int argc, char *const *argv)
 {
   unsigned int errorCount = 0;
+#ifdef __sun
+  struct sigaction act;
+
+  /* Solaris has no way to disable SIGPIPE on socket disconnect. */
+  act.sa_handler = SIG_IGN;
+  sigaction(SIGPIPE, &act, NULL);
+#endif /* __sun */
 
   oneone = (NULL != strrchr (argv[0], (int) '/')) ?
     (NULL != strstr (strrchr (argv[0], (int) '/'), "11")) : 0;
